<?php

namespace forge12\woocommerce\accessories {
    if(!defined('ABSPATH')){
        exit;
    }
    /**
     * dependencies
     */
    require_once('UIMenu.class.php');

    /**
     * Class UI
     * @package forge12\ui
     */
    class UI
    {
        /**
         * @var UI
         */
        private static $instance = null;

        /**
         * @var string
         */
        private $slug = '';
        /**
         * @var string
         */
        private $title = '';
        /**
         * @var string
         */
        private $capabilities;

        /**
         * @param $slug
         * @return UI
         */
        public static function getInstance($slug, $title = 'Dashboard', $capabilities = 'manage_options')
        {
            if (null == self::$instance) {
                self::$instance = new UI($slug, $title, $capabilities);
            }
            return self::$instance;
        }

        /**
         * UI constructor.
         * @param $slug
         */
        private function __construct($slug, $title, $capabilities)
        {
            $this->slug = $slug;
            $this->title = $title;
            $this->capabilities = $capabilities;

            $this->menu = new UIMenu($slug);

            add_action('admin_menu', array($this, 'initAdminMenu'));
        }

        public function addPage($slug, $title, $class, $callback = null, $sidebar = null)
        {
            $this->menu->add($slug, $title, $class, $callback, $sidebar);

            if (null !== $callback && is_callable($callback)) {
                add_action('forge12-plugin-content-' . $this->slug, $callback, 10, 2);
            }
            if (null !== $sidebar && is_callable($callback)) {
                add_action('forge12-plugin-sidebar-' . $this->slug, $sidebar, 10, 2);
            }
        }

        /**
         * Add the WordPress Page for the Settings to the WordPress CMS
         */
        public function initAdminMenu()
        {
            add_menu_page($this->title, $this->title, $this->capabilities, $this->slug, null, 'dashicons-cart');

            $pages = $this->menu->getPages();
            foreach ($pages as $page) {
                /*
                 * Adding to ensure the dashboad overwrites the default page in the menu
                 */
                if ($page['slug'] == $this->slug . "_dashboard") {
                    add_submenu_page($this->slug, $page['title'], $page['title'], 'manage_options', $this->slug, function () {
                        $this->render();
                    });
                } else {
                    add_submenu_page($this->slug, $page['title'], $page['title'], 'manage_options', $page['slug'], function () {
                        $this->render();
                    });
                }
            }
        }

        public function render()
        {
            $page = sanitize_text_field($_GET['page']);
            $page = substr(explode($this->slug, $page)[1], 1);
            ?>
            <div class="forge12-plugin">
                <div class="forge12-plugin-header">
                    <div class="forge12-plugin-header-inner">
                        <img src="<?php echo esc_url(plugin_dir_url(__FILE__)); ?>assets/logo-forge12.png"
                             alt="Forge12 Interactvie GmbH" title="Forge12 Interactive GmbH"/>
                    </div>
                </div>
                <div class="forge12-plugin-menu">
                    <?php $this->menu->render(); ?>
                </div>
                <div class="forge12-plugin-content">
                    <div class="forge12-plugin-content-main">
                        <?php do_action('forge12-plugin-content-' . $this->slug, $this->slug, $page) ?>
                    </div>
                    <div class="forge12-plugin-content-sidebar">
                        <?php do_action('forge12-plugin-sidebar-' . $this->slug, $this->slug, $page) ?>
                    </div>
                </div>
                <div class="forge12-plugin-footer">
                    <div class="forge12-plugin-footer-inner">
                        <img src="<?php echo esc_url(plugin_dir_url(__FILE__)); ?>assets/logo-forge12-dark.png"
                             alt="Forge12 Interactvie GmbH" title="Forge12 Interactive GmbH"/>
                    </div>
                </div>
            </div>
            <?php
        }
    }
}