<?php

namespace forge12\woocommerce\accessories {
    if (!defined('ABSPATH')) {
        exit;
    }

    /**
     * Class UIDashboard
     */
    class UIOptionalAccessories
    {
        /**
         * @var UI
         */
        private $UI;
        /**
         * @var string
         */
        private $domain;

        public function __construct($UI, $domain)
        {
            $this->UI = $UI;
            $this->domain = $domain;

            $UI->addPage(
                'optional_accessoire',
                __('Optional Accessories', $domain),
                '',
                array($this, 'renderContent'),
                array($this, 'renderSidebar')
            );
        }

        /**
         * Get global settings for accessories
         *
         * @return array
         */
        public static function getSettings()
        {
            $atts = array(
                'enable' => 1,
                'priority' => 25,
                'title' => '',
                'title_type' => 'h2',
                'description' => ''
            );

            $attr = get_option('f12-woo-accesoire-settings', true);

            if (!is_array($attr)) {
                $attr = array();
            }

            return array_merge($atts, $attr);
        }


        /**
         * Save on form submit
         */
        private function maybeSave()
        {

            // Check if the form is posted and the nonce is valid
            if (isset($_POST['accessories-settings-submit']) && wp_verify_nonce($_POST['accessories_settings_nonce'], 'accessories_settings_action')) {
                $settings = self::getSettings();

                if (isset($_POST['enable'])) {
                    $settings['enable'] = (int)$_POST['enable'];
                } else {
                    $settings['enable'] = 0;
                }

                if (isset($_POST['priority'])) {
                    $settings['priority'] = (int)$_POST['priority'];
                }

                if (isset($_POST['title'])) {
                    $settings['title'] = sanitize_text_field($_POST['title']);
                }

                if (isset($_POST['title_type'])) {
                    $settings['title_type'] = sanitize_text_field($_POST['title_type']);
                }

                if (isset($_POST['description'])) {
                    $settings['description'] = sanitize_textarea_field($_POST['description']);
                }

                update_option('f12-woo-accesoire-settings', $settings);

                Messages::getInstance()->add(__('Settings updated', 'f12-woo-accessories'), 'success');
            }
        }

        /**
         * Render the content
         *
         * @param $slug
         * @param $page
         */
        public function renderContent($slug, $page)
        {
            // Check if page is dashboard
            if ($page != 'optional_accessoire') {
                return;
            }

            // Check if data should be updated
            $this->maybeSave();

            $settings = self::getSettings();

            $priorityItems = array(
                5 => 'Before product data tabs',
                12 => 'Before upsell products',
                17 => 'Before related products',
                25 => 'After related products'
            );

            $titleTypeItems = array(
                'h2' => 'h2',
                'h3' => 'h3',
                'h4' => 'h4',
                'h5' => 'h5',
                'h6' => 'h6',
                'p' => 'p'
            );

            echo Messages::getInstance()->getAll();
            ?>
            <div class="box">
                <h1><?php _e('Settings', 'f12-woo-accessories'); ?></h1>

                <form action="" method="post" name="save-settings">
                    <div class="option">
                        <div class="label">
                            <label for="enable"><?php _e('Enable Accessories', 'f12-woo-accessories'); ?></label>
                        </div>
                        <div class="input">
                            <input id="enable" type="checkbox" name="enable"
                                   value="1" <?php echo (int)$settings['enable'] == 1 ? 'checked="checked"' : ''; ?>
                            />
                            <p>
                                <?php _e('Use this option to globally enable or disable your accessories.', 'f12-woo-accessories'); ?>
                            </p>
                        </div>
                    </div>

                    <div class="option">
                        <div class="label">
                            <label for="priority"><?php _e('Select Position for Accessories', 'f12-woo-accessories'); ?></label>
                        </div>
                        <div class="input">
                            <select id="priority" name="priority">
                                <?php
                                foreach ($priorityItems as $priority => $label):
                                    ?>
                                    <option value="<?php esc_attr_e($priority); ?>" <?php echo (int)$priority == (int)$settings['priority'] ? ' selected="selected" ' : ''; ?> >
                                        <?php _e($label, 'f12-woo-accessories'); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <p>
                                <?php _e('Select where to display your accessories.', 'f12-woo-accessories'); ?>
                            </p>
                        </div>
                    </div>

                    <div class="option">
                        <div class="label">
                            <label for="title_type"><?php _e('Title/Description', 'f12-woo-accessories'); ?></label>
                        </div>
                        <div class="input">
                            <select id="title_type" name="title_type">
                                <?php
                                foreach ($titleTypeItems as $type => $label):
                                    ?>
                                    <option value="<?php esc_attr_e($type); ?>" <?php echo $type == $settings['title_type'] ? ' selected="selected" ' : ''; ?> >
                                        <?php _e($label, 'f12-woo-accessories'); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <p>
                                <?php _e('Select what the type of the title will be.', 'f12-woo-accessories'); ?>
                            </p>
                            <input type="text" name="title" value="<?php esc_attr_e($settings['title']); ?>"
                                   placeholder="<?php _e('Accessories for this product...', 'f12-woo-accessories'); ?>"/>
                            <p>
                                <?php _e('Customize the title for the frontend. You can also edit the title with Plugins like LocoTranslate. Just search for the placeholder content to edit / translate the content.', 'f12-woo-accessories'); ?>
                            </p>
                            <textarea
                                    name="description"><?php echo esc_textarea($settings['description']); ?></textarea>
                            <p>
                                <?php _e('Add a custom description below the title. This can help to improve your seo scores. Use a plugin like LocoTranslate to translate/add content instead of this textarea to support multiple languages.', 'f12-woo-accessories'); ?>
                            </p>
                        </div>
                    </div>

                    <input type="submit" name="accessories-settings-submit" class="button"
                           value="<?php _e('Save', 'f12-woo-accessories'); ?>"/>

                    <?php
                    wp_nonce_field('accessories_settings_action', 'accessories_settings_nonce');
                    ?>

                </form>
            </div>
            <?php
        }

        /**
         * Render the sidebar
         *
         * @param $slug
         * @param $page
         */
        public function renderSidebar($slug, $page)
        {
            if ($page != "optional_accessoire") {
                return;
            }

            ?>
            <div class="box">
                <h2>
                    <?php _e('Hint:', 'f12-woo-accessories'); ?>
                </h2>
                <p>
                    <?php _e("On the left side you will find additional options for the accessories. You will find the option to add accessories on the product edit pages within woocommerce. (WooCommerce > Product > Edit Product > Linked Products > Accessories)", 'f12-woo-accessories'); ?>
                </p>
            </div>
            <div class="box">
                <h2>
                    <?php _e('Shortcodes:', 'f12-woo-accessories'); ?>
                </h2>
                <p>
                    <?php _e("Use the following shortcode to manually render the optional accessories for a given product.", 'f12-woo-accessories'); ?>
                </p>
                <code>
                    [f12-wc-accessories-optional post_id=""]
                </code>
                <p>
                    <?php _e("Enter the product id as post_id will render the accessories for the given product.", "f12-woo-accessories"); ?>
                </p>
            </div>
            <?php
        }
    }
}